<?php
/*
 +--------------------------------------------------------------------+
 | Copyright CiviCRM LLC. All rights reserved.                        |
 |                                                                    |
 | This work is published under the GNU AGPLv3 license with some      |
 | permitted exceptions and without any warranty. For full license    |
 | and copyright information, see https://civicrm.org/licensing       |
 +--------------------------------------------------------------------+
 */

namespace Civi\Certificates\Event;

use Civi\API\Event\AuthorizedTrait;
use Civi\Core\Event\GenericHookEvent;

/**
 * Class AuthorizeEvent
 *
 * @package Civi\Certificates\Event
 *
 * Determine whether the contact is allowed to download the certificate.
 * For successful execution, at least one listener must invoke
 * $event->authorize().
 *
 * Event name: 'civi.certificates.authorize'
 */
class AuthorizeEvent extends GenericHookEvent {

  use AuthorizedTrait;

  /**
   * The type of certificate (lowercase) (eg. 'membership')
   *
   * @var string
   */
  protected string $certificateType;

  /**
   * The contact that the certificate is being created for
   *
   * @var string
   */
  protected string $contactID;

  /**
   * The Entity for which a certificate is being created
   *
   * @var int
   */
  protected int $entityID;

  /**
   * @return string
   */
  public function getCertificateType(): string {
    return $this->certificateType;
  }

  /**
   * @return string
   */
  public function getContactID(): string {
    return $this->contactID;
  }

  /**
   * @return int
   */
  public function getEntityID(): int {
    return $this->entityID;
  }

  public function __construct(string $certificateType, int $contactID, int $entityID) {
    $this->certificateType = $certificateType;
    $this->contactID = $contactID;
    $this->entityID = $entityID;
  }

}
