<?php

namespace Civi\Certificates;

use Civi\Api4\MessageTemplate;
use Civi\Token\TokenProcessor;
use CRM_Greenregister_ExtensionUtil as E;
use TypeError;

class PDFCertificate {

  /**
   * Call this function to generate and download a PDF "certificate" using the specified messagetemplate and context.
   * This function calls CiviExit() and doesn't return.
   *
   * @param int $messageTemplateID
   * @param array $context
   * @param string $filename
   * @param int $pdfFormatID
   *
   * @return void
   * @throws \CRM_Core_Exception
   * @throws \Civi\API\Exception\UnauthorizedException
   */
  public function download(int $messageTemplateID, array $context, string $filename, int $pdfFormatID = 0) {
    if ($pdfFormatID === 0) {
      // Get the default (or first by ID)
      $pdfFormatID = \Civi\Api4\OptionValue::get(FALSE)
        ->addSelect('id')
        ->addWhere('option_group_id:name', '=', 'pdf_format')
        ->addOrderBy('is_default', 'DESC')
        ->addOrderBy('id', 'ASC')
        ->execute()
        ->first()['id'];
    }
    $filename = \CRM_Utils_File::makeFilenameWithUnicode($filename, '_', 200) . '.pdf';

    $htmlMessage = MessageTemplate::get(FALSE)
      ->addWhere('id', '=', $messageTemplateID)
      ->execute()
      ->first()['msg_html'];

    try {
      $tp = new TokenProcessor(\Civi::dispatcher(), [
        'controller' => get_class(),
        'smarty' => FALSE,
        'schema' => array_keys($context),
      ]);
      $tp->addMessage('body_html', $htmlMessage, 'text/html');

      $tp->addRow()->context($context);
      $tp->evaluate();
    }
    catch (TypeError $e) {
      \Civi::log()->error('certificates: TypeError parsing tokens. Error: ' . $e->getMessage() . '. Available tokens: ' . $tp->getTokens() . '. Found Tokens: ' . $tp->getMessageTokens());
    }

    $rows = $tp->getRows();
    $msgPart = 'body_html';

    $html = [];
    foreach ($rows as $row) {
      $html[] = $row->render($msgPart);
    }
    if (!empty($html)) {
      \CRM_Utils_PDF_Utils::html2pdf($html, $filename, FALSE, $pdfFormatID);
    }

    \CRM_Utils_System::civiExit();
  }

}
