<?php

require_once 'certificates.civix.php';
// phpcs:disable
use CRM_Certificates_ExtensionUtil as E;
// phpcs:enable

/**
 * Implements hook_civicrm_config().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_config/
 */
function certificates_civicrm_config(&$config): void {
  _certificates_civix_civicrm_config($config);
}

/**
 * Implements hook_civicrm_install().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_install
 */
function certificates_civicrm_install(): void {
  _certificates_civix_civicrm_install();
}

/**
 * Implements hook_civicrm_enable().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_enable
 */
function certificates_civicrm_enable(): void {
  _certificates_civix_civicrm_enable();
}

/**
 * Implements print certificate task.
 */
function certificates_civicrm_searchTasks($objectType, &$tasks) {
  if ($objectType === 'event' && (CRM_Core_Permission::check('download participant certificates'))) {
    $tasks[] = [
      'title' => E::ts('Print Certificate'),
      'class' => 'CRM_Certificates_Form_Task',
      'result' => TRUE,
      'is_single_mode' => TRUE,
      'title_single_mode' => E::ts('Print Certificate'),
      'name' => E::ts('Print Certificate'),
      'key' => 'move',
      'weight' => 130,
    ];
  }
}

/**
 * Define Certificates permissions
 */
function certificates_civicrm_permission(array &$permissions): void {
  $prefix = 'Certificates: ';
  $permissions['download participant certificates'] = [
    'label' => $prefix . E::ts('Print all Participant Certificates'),
    'description' => $prefix . E::ts('Allow user to print event attendance certificates for any event'),
  ];
  $permissions['download activity certificates'] = [
    'label' => $prefix . E::ts('Print all Activity Certificates'),
    'description' => $prefix . E::ts('Allow user to print any "activity" certificate'),
  ];
  $permissions['download membership certificates'] = [
    'label' => $prefix . E::ts('Print all Membership Certificates'),
    'description' => $prefix . E::ts('Allow user to print membership certificates for any contact'),
  ];
  $permissions['download own certificate'] = [
    'label' => E::ts('Print own Certificate'),
    'description' => $prefix . E::ts('Allow user to print their own certificate'),
  ];
}
